package hanalife.batch.util;

import java.io.FileInputStream;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.Properties;

import org.apache.log4j.Logger;


/**
* <pre>
* 클래스명    : PropertyLoader
* 클래스설명 : PropertyLoader 프로퍼티파일 로더 - 리소스번들(ResourceBundle)클래스를
 * 이용해서 프로퍼티 파일을 로드한다.
* 프로젝트명 : DOBSCAP
* 작성일자    : 2018-08-01
* 변경이력
* -----------------------------------------------------------------------------
* [변경일자 ][변경자][변경사유-수정내용]
* -----------------------------------------------------------------------------
* [20180801][두비스][캐피탈패키지-최초작성]
* -----------------------------------------------------------------------------
* </pre>
*/
public class PropertyLoader  {
    private static boolean debug = true;
    String propertyFile = null;
    Properties properties = null;

    private static Logger log = Logger.getLogger(PropertyLoader.class);

    public PropertyLoader() {
    }

    public PropertyLoader(String file) {
        this.propertyFile = file;
        load();
    }

    private void trace(Object o) {
        if (debug) {
            log.debug("$PropertyLoader: " + o);
        }
    }

    public String getFile() {
        return this.propertyFile;
    }

    public boolean load() {
        return load(getFile(), Locale.KOREA);
    }

    public boolean load(Locale locale) {
        return load(getFile(), locale);
    }

    /**
     * 프로퍼파일을 로드한다.
     * @param file 프로퍼티파일명
     * @param locale 로케일
     * @return 파일로드 성공여부
     */
    protected boolean load(String file, Locale locale) {
        //null 인경우를 위해서 처리
        properties = new Properties();

        boolean noError = false;
        FileInputStream in = null;

        try {
            in = new FileInputStream(file);
            properties.load(in);
            noError = true;
        } catch (java.io.FileNotFoundException e) {
            in = null;
            log.debug(file + " 을 찾을 수 없습니다.");
            e.printStackTrace();
        } catch (java.io.IOException e) {
            e.printStackTrace();
            log.debug(file + " 을 읽을 수 없습니다.");
        } finally {
            if (in != null) {
                try {
                    in.close();
                } catch (java.io.IOException e) {
                }

                in = null;
            }

            return noError;
        }
    }

    /**
     * ResourceBundle에서 문자열값을 얻는다.
     * sDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
     */
    public String getString(String sKey, final String sDefValue) {

    	log.debug("########### sKey =" + sKey);
    	log.debug("########### sDefValue =" + sDefValue);

    	//String logHome = pl.getString("log.home", batchHm + SEP + "log");

    	if ((this.properties == null) || (sKey == null)) {
            return sDefValue;
        }

        try {
            String sValue = this.properties.getProperty(sKey);

            if ((sValue == null) || (sValue.length() == 0)) {
                return sDefValue;
            } else {
                return sValue;
            }
        } catch (MissingResourceException e) {
            trace(e);

            return sDefValue;
        }
    }

    /**
     * boolean 값을 얻는다. 값이 1이면 true 아니면 false
     * bDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
     */
    public boolean getBoolean(String sKey, final boolean bDefValue) {
        if ((this.properties == null) || (sKey == null)) {
            return bDefValue;
        }

        try {
            String sValue = this.properties.getProperty(sKey);

            if ((sValue == null) || (sValue.length() == 0)) {
                return bDefValue;
            } else {
                sValue = sValue.trim();

                if (sValue.equalsIgnoreCase("true") ||
                        sValue.equalsIgnoreCase("yes") ||
                        (sValue.charAt(0) == '1')) {
                    return true;
                } else {
                    return false;
                }
            }
        } catch (MissingResourceException e) {
            trace(e);

            return bDefValue;
        }
    }

    /**
     * ResourceBundle에서 정수값을 얻는다.
     * nDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
     */
    public int getInt(String sKey, final int nDefValue) {
        if ((this.properties == null) || (sKey == null)) {
            return nDefValue;
        }

        try {
            String sValue = this.properties.getProperty(sKey);

            if ((sValue == null) || (sValue.length() == 0)) {
                return nDefValue;
            } else {
                return Integer.parseInt(sValue);
            }
        } catch (Exception e) {
            trace(e);

            return nDefValue;
        }
    }

    /**
     * ResourceBundle에서 문자값을 얻는다.
     * cDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
     */
    public char getChar(String sKey, final char cDefValue) {
        if ((this.properties == null) || (sKey == null)) {
            return cDefValue;
        }

        try {
            String sValue = this.properties.getProperty(sKey);

            if ((sValue == null) || (sValue.length() == 0)) {
                return cDefValue;
            } else {
                return sValue.charAt(0);
            }
        } catch (Exception e) {
            trace(e);

            return cDefValue;
        }
    }

    /**
     * TODO 테스트때문에 만듬. 나중에 지울것.
     * @param args
     */
    public static void main(String[] args) {
        // 필수 환경변수 -------------------------------------------
        // 배치 홈을 읽는 부분 필요.
        String batchHome = System.getProperty("batch.home");

        // 개별 config 파일위치 설정
        String config = System.getProperty("batch.config");

        // 개별 logconfig 파일위치 설정
        String logConfig = System.getProperty("batch.log.config");

        // 옵션 환경변수 -----------------------------------------------
        // 개별 xml 파일위치 설정
        String xmlFile = System.getProperty("batch.xmlfile");

        if ((batchHome == null) || (config == null) || (logConfig == null)) {
            printUsage();
            System.exit(-1);
        }

        String filesep = System.getProperty("file.separator");

        //        config = "c:\\jeus33\\lib\\application\\config\\batch.config";
        //config = "c:/jeus33/lib/application/config/batch.config";

        config = "c:/batch/Batch_home/config/batch.config";

        PropertyLoader pl = new PropertyLoader(config);

        String version = pl.getString("version", "-");
        String dbDriver = pl.getString("db.driver",
                "COM.ibm.db2.jdbc.app.DB2Driver");
        String dbUrl = pl.getString("db.url", "jdbc:db2:unittest");
        String dbUser = pl.getString("db.user", "wuser");
        String dbPassword = pl.getString("db.password", "wuser");

        String dataHome = pl.getString("data.home", batchHome + filesep +
                "data");
        String xmlHome = pl.getString("xml.home",
                batchHome + filesep + "include");
        String logHome = pl.getString("log.home", batchHome + filesep + "log");

        //        log.debug("version    = " + version);
        //        log.debug("dbDriver   = " + dbDriver);
        //        log.debug("dbUrl      = " + dbUrl);
        //        log.debug("dbUser     = " + dbUser);
        //        log.debug("dbPassword = " + dbPassword);
        //
        //        log.debug("dataHome   = " + dataHome);
        //        log.debug("xmlHome    = " + xmlHome);
        //        log.debug("logHome    = " + logHome);
    }

    /**
     * TODO 테스트때문에 만듬. 나중에 지울것.
     * @param args
     */
    private static void printUsage() {
        log.debug("환경설정이 없습니다. 아래 환경변수를 설정하십시오.");
        log.debug(" -Dbatch.home=\"\"       배치 Home 디렉토리");
        log.debug(" -Dbatch.config=\"\"     배치 환경 파일");
        log.debug(" -Dbatch.log.config=\"\" 배치 로그환경파일");
    }

    //    private static boolean debug = true;
    //    String propertyFile = null;
    //    Properties properties = null;
    //
    //    public PropertyLoader() {
    //    }
    //
    //    public PropertyLoader(String file) {
    //        this.propertyFile = file;
    //        load();
    //    }
    //
    //    private void trace(Object o) {
    //        if (debug) {
    //            log.debug("$PropertyLoader: " + o);
    //        }
    //    }
    //
    //    public String getFile() {
    //        return this.propertyFile;
    //    }
    //
    //    public boolean load() {
    //        return load(getFile(), Locale.KOREA);
    //    }
    //
    //    public boolean load(Locale locale) {
    //        return load(getFile(), locale);
    //    }
    //
    //    /**
    //     * 프로퍼파일을 로드한다.
    //     * @param file 프로퍼티파일명
    //     * @param locale 로케일
    //     * @return 파일로드 성공여부
    //     */
    //    protected boolean load(String file, Locale locale) {
    //        //null 인경우를 위해서 처리
    //        properties = new Properties();
    //
    //        boolean noError = false;
    //        FileInputStream in = null;
    //
    //        try {
    //            in = new FileInputStream(file);
    //            properties.load(in);
    //            noError = true;
    //        } catch (java.io.FileNotFoundException e) {
    //            in = null;
    //            log.debug(file + " 을 찾을 수 없습니다.");
    //        } catch (java.io.IOException e) {
    //            log.debug(file + " 을 읽을 수 없습니다.");
    //        } finally {
    //            if (in != null) {
    //                try {
    //                    in.close();
    //                } catch (java.io.IOException e) {
    //                }
    //
    //                in = null;
    //            }
    //
    //            return noError;
    //        }
    //    }
    //
    //    /**
    //     * ResourceBundle에서 문자열값을 얻는다.
    //     * sDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
    //     */
    //    public String getString(String sKey, final String sDefValue) {
    //        if ((this.properties == null) || (sKey == null)) {
    //            return sDefValue;
    //        }
    //
    //        try {
    //            String sValue = this.properties.getProperty(sKey);
    //
    //            if ((sValue == null) || (sValue.length() == 0)) {
    //                return sDefValue;
    //            } else {
    //                return sValue;
    //            }
    //        } catch (MissingResourceException e) {
    //            trace(e);
    //
    //            return sDefValue;
    //        }
    //    }
    //
    //    /**
    //     * boolean 값을 얻는다. 값이 1이면 true 아니면 false
    //     * bDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
    //     */
    //    public boolean getBoolean(String sKey, final boolean bDefValue) {
    //        if ((this.properties == null) || (sKey == null)) {
    //            return bDefValue;
    //        }
    //
    //        try {
    //            String sValue = this.properties.getProperty(sKey);
    //
    //            if ((sValue == null) || (sValue.length() == 0)) {
    //                return bDefValue;
    //            } else {
    //                sValue = sValue.trim();
    //
    //                if (sValue.equalsIgnoreCase("true") ||
    //                        sValue.equalsIgnoreCase("yes") ||
    //                        (sValue.charAt(0) == '1')) {
    //                    return true;
    //                } else {
    //                    return false;
    //                }
    //            }
    //        } catch (MissingResourceException e) {
    //            trace(e);
    //
    //            return bDefValue;
    //        }
    //    }
    //
    //    /**
    //     * ResourceBundle에서 정수값을 얻는다.
    //     * nDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
    //     */
    //    public int getInt(String sKey, final int nDefValue) {
    //        if ((this.properties == null) || (sKey == null)) {
    //            return nDefValue;
    //        }
    //
    //        try {
    //            String sValue = this.properties.getProperty(sKey);
    //
    //            if ((sValue == null) || (sValue.length() == 0)) {
    //                return nDefValue;
    //            } else {
    //                return Integer.parseInt(sValue);
    //            }
    //        } catch (Exception e) {
    //            trace(e);
    //
    //            return nDefValue;
    //        }
    //    }
    //
    //    /**
    //     * ResourceBundle에서 문자값을 얻는다.
    //     * cDefValue는 값을 얻지 못했을 때 기본값으로 리턴하는 값이다.
    //     */
    //    public char getChar(String sKey, final char cDefValue) {
    //        if ((this.properties == null) || (sKey == null)) {
    //            return cDefValue;
    //        }
    //
    //        try {
    //            String sValue = this.properties.getProperty(sKey);
    //
    //            if ((sValue == null) || (sValue.length() == 0)) {
    //                return cDefValue;
    //            } else {
    //                return sValue.charAt(0);
    //            }
    //        } catch (Exception e) {
    //            trace(e);
    //
    //            return cDefValue;
    //        }
    //    }
    //
    //    /**
    //     * TODO 테스트때문에 만듬. 나중에 지울것.
    //     * @param args
    //     */
    //    public static void main(String[] args) {
    //        // 필수 환경변수 -------------------------------------------
    //        // 배치 홈을 읽는 부분 필요.
    //        String batchHome = System.getProperty("batch.home");
    //
    //        // 개별 config 파일위치 설정
    //        String config = System.getProperty("batch.config");
    //
    //        // 개별 logconfig 파일위치 설정
    //        String logConfig = System.getProperty("batch.log.config");
    //
    //        // 옵션 환경변수 -----------------------------------------------
    //        // 개별 xml 파일위치 설정
    //        String xmlFile = System.getProperty("batch.xmlfile");
    //
    //        if ((batchHome == null) || (config == null) || (logConfig == null)) {
    //            printUsage();
    //            System.exit(-1);
    //        }
    //
    //        String filesep = System.getProperty("file.separator");
    //
    //        //        config = "c:\\jeus33\\lib\\application\\config\\batch.config";
    //        config = "c:/jeus33/lib/application/config/batch.config";
    //
    //        PropertyLoader pl = new PropertyLoader(config);
    //
    //        String version = pl.getString("version", "-");
    //        String dbDriver = pl.getString("db.driver",
    //                "COM.ibm.db2.jdbc.app.DB2Driver");
    //        String dbUrl = pl.getString("db.url", "jdbc:db2:unittest");
    //        String dbUser = pl.getString("db.user", "wuser");
    //        String dbPassword = pl.getString("db.password", "wuser");
    //
    //        String dataHome = pl.getString("data.home", batchHome + filesep +
    //                "data");
    //        String xmlHome = pl.getString("xml.home",
    //                batchHome + filesep + "include");
    //        String logHome = pl.getString("log.home", batchHome + filesep + "log");
    //
    //        //        log.debug("version    = " + version);
    //        //        log.debug("dbDriver   = " + dbDriver);
    //        //        log.debug("dbUrl      = " + dbUrl);
    //        //        log.debug("dbUser     = " + dbUser);
    //        //        log.debug("dbPassword = " + dbPassword);
    //        //
    //        //        log.debug("dataHome   = " + dataHome);
    //        //        log.debug("xmlHome    = " + xmlHome);
    //        //        log.debug("logHome    = " + logHome);
    //    }
    //
    //    /**
    //     * TODO 테스트때문에 만듬. 나중에 지울것.
    //     * @param args
    //     */
    //    private static void printUsage() {
    //        log.debug("환경설정이 없습니다. 아래 환경변수를 설정하십시오.");
    //        log.debug(" -Dbatch.home=\"\"       배치 Home 디렉토리");
    //        log.debug(" -Dbatch.config=\"\"     배치 환경 파일");
    //        log.debug(" -Dbatch.log.config=\"\" 배치 로그환경파일");
    //    }
}
