package hanalife.c.co.service.impl;

import java.util.ArrayList;
import java.util.List;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import hanalife.batch.ProcObj;
import hanalife.c.co.contants.Constants;
import hanalife.c.co.iEnum.MsgEnum;
import hanalife.c.co.mapper.CommBizMapper;
import hanalife.c.co.mapper.CtCommCdDescMapper;
import hanalife.c.co.mapper.SearchLoanSeqMapper;
import hanalife.c.co.mapper.dto.CommBizINDTO;
import hanalife.c.co.mapper.dto.CtCommCdDescDTO;
import hanalife.c.co.mapper.dto.GetHpNoByLoanNoDTO;
import hanalife.c.co.mapper.dto.HtWorkCharDdDTO;
import hanalife.c.co.mapper.dto.ProcGetNextNumberDTO;
import hanalife.c.co.mapper.dto.SearchLoanSeqDTO;
import hanalife.c.co.service.CommBizService;
import hanalife.c.co.util.StringUtil;
import hanalife.c.co.vo.CommCdVO;
import hanalife.c.co.vo.SearchCommCdOutVO;
import hanalife.c.co.vo.SearchCommCdVO;
import hanalife.c.co.vo.SearchLoanSeqVO;
import hanalife.r.co.rc.service.RcptRCService;
import hanalife.r.zz.mapper.ProcSysMapper;
import hanalife.r.zz.mapper.dto.SearchBatchProcInfoOutDTO;
import hanalife.util.BizException;

/**
 * <pre>
 * 프로젝트명   : 하나생명 가계대출 시스템(DOBSCAP)
 * 클래스명     : CommBizUtil.java Class
 * 클래스설명   : 업무별 공통 Util Service
 * 작성일자     : 2023. 4. 5.
 * 작성자명     : 70279 / 가계대출 시스템 구축
 * Copyrightⓒ2022 HanaLife Insurance, All Rights Reserved.
 * -----------------------------------------------------------------------------
 * Modification Information
 * -----------------------------------------------------------------------------
 * [  수정일자  ][수정자][변경사유-수정내용]
 * -----------------------------------------------------------------------------
 * [2023. 4. 5.][70279 ][최초작성]
 * -----------------------------------------------------------------------------
 * Method Information
 * -----------------------------------------------------------------------------
 * 1. SearchLoanSeq     : 대출번호/순번 존재여부 조회
 * 2. isWorkDt          : 영업일 여부 조회
 * 3. gvnoDsrcNo        : 예/가수번호 채번
 * 4. gvnoLoanNo        : 대출번호 채번
 * 5. addWkdt           : 영업일 날짜계산 (영업일, input이 휴일일경우 당일포함)
 * -----------------------------------------------------------------------------
 * </pre>
 */
@Service("CommBizService")
public class CommBizServiceImpl implements CommBizService {

    private final Logger LOGGER = LoggerFactory.getLogger(CommBizServiceImpl.class);

    /** 공통오류코드 및 오류메시지내용 전역 변수 선언 */
    private MsgEnum msgEnum;

    /** 업무별 공통 Mapper 전역 변수 선언 */
    @Autowired
    private CommBizMapper commBizMapper;

    /** 공통코드 및 공통코드목록조회 Mapper 전역 변수 선언 */
    @Autowired
    private CtCommCdDescMapper ctCommCdDescMapper;

    /** 대출번호/순번/관리번호 조회 Mapper 전역 변수 선언 */
    @Autowired
    private SearchLoanSeqMapper searchLoanSeqMapper;

    @Autowired
    private ProcSysMapper procSysMapper;

    @Autowired
    private RcptRCService rcptService;

    /**
     * <pre>
     * 메소드명 : SearchLoanSeq
     * 설명 : 대출번호/순번 존재여부 조회
     * 메소드인수1: 대출번호, 대출순번, 관리번호
     * 사용예) CommBizUtil.SearchLoanSeq(대출번호, 대출순번, 관리번호)
     * 메소드리턴값: SearchLoanSeqVO(대출번호, 대출순번, 관리번호, 최종여부)
     * </pre>
     */
    @Override
    public SearchLoanSeqVO SearchLoanSeq(String pstrLoanNo, String pstrLoanSeq, String pstrMngNo) throws Exception {

        /** 결과값 출력 객체 VO 선언 및 정상 초기값 설정 */
        SearchLoanSeqVO resultVo = new SearchLoanSeqVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        if ( StringUtil.isEmpty(pstrLoanNo) == true
            && StringUtil.isEmpty(pstrLoanSeq) == true
            && StringUtil.isEmpty(pstrMngNo) == true ) {
            resultVo.setRsltCd(msgEnum.ISNULL_LOAN_NO.getErrorCd());
            resultVo.setRsltCntn("대출번호, 순번, 관리번호가 입력되지 않았습니다.");
            return resultVo;
        }

        try {
            SearchLoanSeqDTO inDto  = new SearchLoanSeqDTO();
            inDto.setLoanNo(pstrLoanNo); /* 대출번호 */
            inDto.setLoanSeq(pstrLoanSeq); /* 대출순번 */
            inDto.setMngNo(pstrMngNo); /* 관리번호 */
            SearchLoanSeqDTO resultDTO = searchLoanSeqMapper.checkExistLoan(inDto);
            if ( resultDTO == null ) {
                /** 입력 항목값에 따른 오류메시지 내용 결과값 설정 */
                resultVo.setRsltCd(msgEnum.ISNULL_LOAN_NO.getErrorCd());
                resultVo.setRsltCntn("존재하지 않는 대출번호/순번입니다.");
                if ( StringUtil.isEmpty(pstrLoanSeq) == true ) {
                    resultVo.setRsltCntn("존재하지 않는 대출번호입니다.");
                }
                else if ( StringUtil.isEmpty(pstrMngNo) == false ) {
                    resultVo.setRsltCntn("존재하지 않는 관리번호입니다.");
                }
                return resultVo;
            }
            resultVo.setLoanNo(resultDTO.getLoanNo()); /* 대출번호 */
            resultVo.setLoanSeq(resultDTO.getLoanSeq()); /* 대출순번 */
            resultVo.setMngNo(resultDTO.getMngNo()); /* 관리번호 */
            resultVo.setLoanLastFg(resultDTO.getLoanLastFg()); /* 최종여부 */
        }
        catch ( Exception e ) {
            LOGGER.info(e.toString());
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.toString());
        }

        return resultVo;
    }

    /** 공통 영업일자 Util ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■ */
    /**
     * <pre>
     * 메소드명 : isWorkDt
     * 설 명 : 영업일 여부
     * 메소드인수 : {String} pstWorkDt 일자(yyyyMMdd)
     * 리 턴 값 : boolean
     * </pre>
     */
    @Override
    public boolean isWorkDt(String pstWorkDt) {

        /** 영업일 조회 입력일자 미입력 시 영업일자아님(false) 처리 수행 */
        if ( StringUtil.isEmpty(pstWorkDt) == true ) {
            return false;
        }

        try {
            HtWorkCharDdDTO inDto = new HtWorkCharDdDTO();
            inDto.setAttdDt(pstWorkDt); /* 영업일자 */
            HtWorkCharDdDTO resultDto = commBizMapper.selectWorkDt(inDto);

            if ( resultDto == null || "AA0".equals(resultDto.getCharDivCd()) == false ) {
                return false;
            }
        }
        catch ( Exception e ) {
            /** 오류 발생시 영업일 아님으로 결과값 return */
            return false;
        }

        return true;
    }

    /**
     * <pre>
     * 메소드명 : isWorkDt
     * 설 명 : 영업일 여부
     * 메소드인수 : {String} pstWorkDt 일자(yyyyMMdd)
     * 리 턴 값 : boolean
     * </pre>
     * @throws Exception
     */
    @Override
    public boolean isOprTime(String dttm) throws Exception {

        /** 이용시간 미입력 시 이용시간아님(false) 처리 수행 */
        if ( StringUtil.isEmpty(dttm) == true ) {
            return false;
        }

        CommCdVO inVO = new CommCdVO();
        	inVO.setCdKindNo("RTM001");
        	inVO.cdNmDiv = "RTM001";
        	inVO.setEngNm("MIDRMBR");

        List<CommCdVO> outVO = commBizMapper.searchCommCdList(inVO);

        return StringUtil.isBetween(dttm, outVO.get(0).getClas1(), outVO.get(0).getClas2());
    }
    /**
     * <pre>
     * 메소드명     : isLastWkdt
     * 설 명        : 최근영업일 - 입력된 날짜보다 작은 가장 최근 과거영업일
     * 메소드인수   : {String} pstWorkDt : 일자(yyyyMMdd)
     *                {String} pstrIncludeFlag : 1(Y)=당일포함, 0(N)=당일제외
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    @Override
    public String isLastWkdt(String pstWorkDt, String pstrIncludeFlag) {

        String lstrResultWkDt   = "";   /* 출력 영업일자 초기값 설정 */
        String lstrIncludeFlag  = "N";  /* 당일자 포함 여부 변수 선언 */
        if ( "1".equals(pstrIncludeFlag) == true || "Y".equals(pstrIncludeFlag) == true ) {
            lstrIncludeFlag = "Y";
        }
        try {
            HtWorkCharDdDTO inDto = new HtWorkCharDdDTO();
            inDto.setAttdDt(pstWorkDt); /* 영업일자 */
            inDto.setIncludeFlagYn(lstrIncludeFlag); /* 당일포함여부(Y,1), 당일미포함(N,0) */
            HtWorkCharDdDTO resultDto = commBizMapper.selectLastWkdt(inDto);
            if ( resultDto != null ) {
                lstrResultWkDt = resultDto.getAttdDt(); /* 최근 과거영업일자 */
            }
        }
        catch ( Exception e ) {
            /** 오류 발생시 영업일 아님으로 결과값 */
            lstrResultWkDt = "";
        }

        return lstrResultWkDt;
    }

    /**
     * <pre>
     * 메소드명     : isArrvWkdt
     * 설 명        : 도래영업일 - 입력된 날짜보다 작은 큰 최근 미래영업일
     * 메소드인수   : {String} pstWorkDt : 일자(yyyyMMdd)
     *                {String} pstrIncludeFlag : 1(Y)=당일포함, 0(N)=당일제외
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    @Override
    public String isArrvWkdt(String pstWorkDt, String pstrIncludeFlag) {

        String lstrResultWkDt   = "";   /* 출력 영업일자 초기값 설정 */
        String lstrIncludeFlag  = "N";  /* 당일자 포함 여부 변수 선언 */
        if ( "1".equals(pstrIncludeFlag) == true || "Y".equals(pstrIncludeFlag) == true ) {
            lstrIncludeFlag = "Y";
        }
        try {
            HtWorkCharDdDTO inDto = new HtWorkCharDdDTO();
            inDto.setAttdDt(pstWorkDt); /* 영업일자 */
            inDto.setIncludeFlagYn(lstrIncludeFlag); /* 당일포함여부(Y,1), 당일미포함(N,0) */
            HtWorkCharDdDTO resultDto = commBizMapper.selectArrvWkdt(inDto);
            if ( resultDto != null ) {
                lstrResultWkDt = resultDto.getAttdDt(); /* 최근 미래영업일자 */
            }
        }
        catch ( Exception e ) {
            /** 오류 발생시 영업일 아님으로 결과값 */
            lstrResultWkDt = "";
        }

        return lstrResultWkDt;
    }

    /**
     * <pre>
     * 메소드명     : isMonthNWkDt
     * 설 명        : 월 n 번째 영업일 (말영업일은 -1)
     * 메소드인수   : {String} pstYearMm : 년월(yyyyMM)
     *                {String} pstrDay > 0 이면 번째 영업일, 0=말영업일
     * 리 턴 값     : {String} yyyyMMdd
     * </pre>
     */
    @Override
    public String isMonthNWkDt(String pstYearMm, int pstrDay) {

        String lstrResultWkDt   = "";   /* 출력 영업일자 초기값 설정 */
        String lstrIncludeFlag  = "Y";  /* 월 n 번째 영업일자 조회를 위한 입력 초기값 설정 */
        if ( pstrDay <= 0 ) {
            pstrDay = Math.abs(pstrDay);
            lstrIncludeFlag  = "N";  /* 말영업일 -1 을 위한 입력값 변수 선언 */
        }

        try {
            HtWorkCharDdDTO inDto = new HtWorkCharDdDTO();
            inDto.setAttdDt(pstYearMm); /* 년월 */
            inDto.setDayCnt(String.valueOf(pstrDay)); /* 월 n 번째 영업일 */
            inDto.setIncludeFlagYn(lstrIncludeFlag);  /* Y:월 n 번째 영업일조회, N:말영업일-1 */
            HtWorkCharDdDTO resultDto = commBizMapper.selectLastWkdt(inDto);
            if ( resultDto != null ) {
                lstrResultWkDt = resultDto.getAttdDt(); /* 최근 미래영업일자 */
            }
        }
        catch ( Exception e ) {
            /** 오류 발생시 영업일 아님으로 결과값 */
            lstrResultWkDt = "";
        }

        return lstrResultWkDt;
    }


    /** 공통코드 Util ■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■■ */
	/**
	 * <p>메소드명	    : searchCommCd</p>
	 * <p>설　　명	    : 공통코드 조회</p>
	 * <p>메소드인수	: {String} pstrCdKindNo : 코드종류번호, {String} pstrCdDescNo : 코드상세번호
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getSearchCommCd() VO 객체는 조회된 공통코드 VO
	 */
	@Override
    public SearchCommCdOutVO searchCommCd(String pstrCdKindNo, String pstrCdDescNo) throws Exception {

        /** 공통코드 조회 입력값 전달 객체 선언 및 입력값 대입 */
		SearchCommCdVO inVo = new SearchCommCdVO();
        inVo.setCdKindNo(pstrCdKindNo); /* 코드종류번호 */
        inVo.setCdDescNo(pstrCdDescNo); /* 코드상세번호 */

        /** 공통코드 조회 서비스 호출 수행 후 결과값 전달 */
        SearchCommCdOutVO resultVo = searchCommCd(inVo);

		return resultVo;
	}

	/**
	 * <p>메소드명	    : searchCommCd</p>
	 * <p>설　　명	    : 공통코드 조회</p>
	 * <p>메소드인수	: {SearchCommCdVO} inVo : 코드조회 입력 항목 VO </p>
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getSearchCommCd() VO 객체는 조회된 공통코드 VO
	 */
	@Override
    public SearchCommCdOutVO searchCommCd(SearchCommCdVO inVo) throws Exception {

        /** 공통코드 조회 결과값 전달 객체 선언 */
        SearchCommCdOutVO resultVo = new SearchCommCdOutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /** 공통코드 조회 입력값 검증 수행, 미입력 시 오류 출력 */
        if ( StringUtil.isEmpty(inVo.getCdKindNo()) == true
                || StringUtil.isEmpty(inVo.getCdDescNo()) == true ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn("[공통코드]코드종류번호(코드상세번호) 입력값이 존재하지 않습니다.");
            return resultVo;
        }

        try {
            /** 공통코드 조회 Mapper(Dao) 호출 입력 객체 생성 및 입력값 대입 */
            CtCommCdDescDTO inDto = new CtCommCdDescDTO();
            inDto.setCdKindNo(inVo.getCdKindNo()); /* 코드_종류_번호 */
            inDto.setCdDescNo(inVo.getCdDescNo()); /* 코드_상세_번호 */
            inDto.setKorNm(StringUtil.nvl(inVo.getKorNm())); /* 한글명(cdDescKorNm) */
            inDto.setEngNm(StringUtil.nvl(inVo.getEngNm())); /* 영어명 */
            inDto.setShrtNm(StringUtil.nvl(inVo.getShrtNm())); /* 단축명 */
            inDto.setEtcNm(StringUtil.nvl(inVo.getEtcNm())); /* 기타명 */
            inDto.setClas1(StringUtil.nvl(inVo.getClas1())); /* 분류1 */
            inDto.setClas2(StringUtil.nvl(inVo.getClas2())); /* 분류2 */

            /** 공통코드 조회 Mapper(Dao) 호출 수행 */
            CtCommCdDescDTO resultDto = ctCommCdDescMapper.searchCommCd(inDto);
            if ( resultDto == null ) {
                resultVo.setRsltCd(msgEnum.NOT_FOUND.getErrorCd());
                resultVo.setRsltCntn(msgEnum.NOT_FOUND.getErrorCn());
                return resultVo;
            }

            /** 공통코드 결과값 객체 생성 및 결과값 대입 */
            SearchCommCdVO targetIO = new SearchCommCdVO();
            targetIO.setCdKindNo(resultDto.getCdKindNo()); /* 코드_종류_번호 */
            targetIO.setCdDescNo(resultDto.getCdDescNo()); /* 코드_상세_번호 */
            targetIO.setCd(resultDto.getCd()); /* 코드(cdDescNo) */
            targetIO.setNm(resultDto.getNm()); /* 코드명(cdDescKorNm) */
            targetIO.setCdNm(resultDto.getCdNm()); /* 코드+명(cd+''+nm) */
            targetIO.setKorNm(resultDto.getKorNm()); /* 한글명(cdDescKorNm) */
            targetIO.setEngNm(resultDto.getEngNm()); /* 영어명 */
            targetIO.setShrtNm(resultDto.getShrtNm()); /* 단축명 */
            targetIO.setEtcNm(resultDto.getEtcNm()); /* 기타명 */
            targetIO.setClas1(resultDto.getClas1()); /* 분류1 */
            targetIO.setClas2(resultDto.getClas2()); /* 분류2 */

            /** 공통코드 결과값 출력 VO 대입 */
            resultVo.setSearchCommCd(targetIO);
        }
        catch ( Exception e ) {
            /** 시스템 오류 발생시 응답코드 결과값 생성 */
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
        }
		return resultVo;
	}

	/**
	 * <p>메소드명	    : searchCommCdList</p>
	 * <p>설　　명	    : 코드종류번호에 따른 공통코드 목록조회</p>
	 * <p>메소드인수	: {String} pstrCdKindNo : 코드종류번호
	 * <p>리　턴　값	: {SearchCommCdOutVO} resultVo </p>
     *                     resultVo.getRsltCd == "0000" 이면 정상, 그외는 오류
     *                     resultVo.getListSearchCommCd() VO 객체는 조회된 공통코드목록 VO
	 */
	@Override
    public SearchCommCdOutVO searchCommCdList(String pstrCdKindNo) throws Exception {

        /** 공통코드 목록조회 결과값 전달 객체 선언 */
        SearchCommCdOutVO resultVo = new SearchCommCdOutVO();
        resultVo.setRsltCd(msgEnum.SUCCESS.getErrorCd());
        resultVo.setRsltCntn(msgEnum.SUCCESS.getErrorCn());

        /** 공통코드 목록조회 입력값 검증 수행, 미입력 시 오류 출력 */
        if ( StringUtil.isEmpty(pstrCdKindNo) == true ) {
            resultVo.setRsltCd(msgEnum.IS_EMPTY.getErrorCd());
            resultVo.setRsltCntn("[공통코드]코드종류번호 입력값이 존재하지 않습니다.");
            return resultVo;
        }

        try {
            /** 공통코드 목록조회 Mapper(Dao) 호출 입력 객체 생성 및 입력값 대입 */
            CtCommCdDescDTO inDto = new CtCommCdDescDTO();
            inDto.setCdKindNo(pstrCdKindNo); /* 코드_종류_번호 */

            /** 공통코드 목록조회 Mapper(Dao) 호출 수행 */
            List<CtCommCdDescDTO> resultDto = ctCommCdDescMapper.searchCommCdList(inDto);

            if ( resultDto == null ) {
                resultVo.setRsltCd(msgEnum.NOT_FOUND.getErrorCd());
                resultVo.setRsltCntn(msgEnum.NOT_FOUND.getErrorCn());
                return resultVo;
            }

            /** 공통코드 목록조회 결과값 List 객체 선언 및 결과값 반복 수행으로 대입 */
            List<SearchCommCdVO> resultListVo = new ArrayList<SearchCommCdVO>();
            for ( CtCommCdDescDTO sourceIO : resultDto ) {
                /** 공통코드 결과값 객체 생성 및 결과값 대입 */
                SearchCommCdVO targetIO = new SearchCommCdVO();
                targetIO.setCdKindNo(sourceIO.getCdKindNo()); /* 코드_종류_번호 */
                targetIO.setCdDescNo(sourceIO.getCdDescNo()); /* 코드_상세_번호 */
                targetIO.setCd(sourceIO.getCd()); /* 코드(cdDescNo) */
                targetIO.setNm(sourceIO.getNm()); /* 코드명(cdDescKorNm) */
                targetIO.setCdNm(sourceIO.getCdNm()); /* 코드+명(cd+''+nm) */
                targetIO.setKorNm(sourceIO.getKorNm()); /* 한글명(cdDescKorNm) */
                targetIO.setEngNm(sourceIO.getEngNm()); /* 영어명 */
                targetIO.setShrtNm(sourceIO.getShrtNm()); /* 단축명 */
                targetIO.setEtcNm(sourceIO.getEtcNm()); /* 기타명 */
                targetIO.setClas1(sourceIO.getClas1()); /* 분류1 */
                targetIO.setClas2(sourceIO.getClas2()); /* 분류2 */
                resultListVo.add(targetIO);
            }
            /** 공통코드 목록 결과값 출력 VO 대입 */
            resultVo.setListSearchCommCd(resultListVo);
        }
        catch ( Exception e ) {
            /** 시스템 오류 발생시 응답코드 결과값 생성 */
            resultVo.setRsltCd(msgEnum.ERR_SYSTEM.getErrorCd());
            resultVo.setRsltCntn(e.getMessage());
        }

		return resultVo;
	}

    /**
     * <p>메소드명   : getCodeNm</p>
     * <p>설　　명   : 해당 필드명의 공통코드 값을 구한다.</p>
     * <p>메소드인수 : {String} pstrCdKindNo : 코드종류번호, {String} pstrCdDescNo : 코드상세번호, {String} pstrColNm : 코드칼럼명
     * <p>리　턴　값 : String</p>
     */
    @Override
    public String getCodeNm(String pstrCdKindNo, String pstrCdDescNo, String pstrColNm) throws Exception {
        SearchCommCdVO inVo = new SearchCommCdVO();
        inVo.setCdKindNo(pstrCdKindNo); /* 코드_종류_번호 */
        inVo.setCdDescNo(pstrCdDescNo); /* 코드_상세_번호 */
        return this.getCodeNm(inVo, pstrColNm);
    }

    /**
     * <p>메소드명   : getCodeNm</p>
     * <p>설　　명   : 해당 필드명의 공통코드 값을 구한다.</p>
     * <p>메소드인수 : SearchCommCdVO, pstrColNm</p>
     * <p>리　턴　값 : String</p>
     */
    @Override
    public String getCodeNm(SearchCommCdVO inVo, String pstrColNm) throws Exception {

        String CD      = "cd";
        String NM      = "nm";
        String CD_NM   = "cdNm";
        String KOR_NM  = "korNm";
        String ENG_NM  = "engNm";
        String SHRT_NM = "shrtNm";
        String ETC_NM  = "etcNm";
        String CLAS1   = "clas1";
        String CLAS2   = "clas2";

        SearchCommCdOutVO cdVO = searchCommCd(inVo);
        /** 조회 결과 오류 발생시 "" 초기값 return 설정 */
        if ( msgEnum.SUCCESS.getErrorCd().equals(cdVO.getRsltCd()) == false ) {
            LOGGER.warn("공통코드조회 결과 => 0건");
            return "";
        }

        if (StringUtil.in(pstrColNm, CD)) {
            return cdVO.getSearchCommCd().getCd();
        }
        else if (StringUtil.in(pstrColNm, CD_NM)) {
            return cdVO.getSearchCommCd().getCdNm();
        }
        else if (StringUtil.in(pstrColNm, NM, KOR_NM)) {
            return cdVO.getSearchCommCd().getKorNm();
        }
        else if (StringUtil.in(pstrColNm)) {
            return cdVO.getSearchCommCd().getEngNm();
        }
        else if (StringUtil.in(pstrColNm, SHRT_NM)) {
            return cdVO.getSearchCommCd().getShrtNm();
        }
        else if (StringUtil.in(pstrColNm, ETC_NM)) {
            return cdVO.getSearchCommCd().getEtcNm();
        }
        else if (StringUtil.in(pstrColNm, CLAS1)) {
            return cdVO.getSearchCommCd().getClas1();
        }
        else if (StringUtil.in(pstrColNm, CLAS2)) {
            return cdVO.getSearchCommCd().getClas2();
        }
        else {
            LOGGER.warn("CommBizUtil.getCodeNm] 컬럼명을 확인하세요. => " + pstrColNm);
            return "";
        }
    }

	/**
	 * <p>메소드명		: gvnoDsrcNo</p>
	 * <p>설명			: 예가수번호채번</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public String gvnoDsrcNo(String acctDt) {
		if ("".equals(acctDt) || (acctDt.length() < 8)) {
			throw new BizException("예가수 번호 채번중 에러발생 : 회계일자가 입력되지 않았습니다.");
		}

		String sRtn = "";
		try {
			sRtn = "S" + StringUtil.getFormatDt(acctDt,"").substring(2,6) + rcptService.getNextNum();
		} catch ( Exception e ) {
			return "";
		}
		return sRtn;
	}


	/**
	 * <p>메소드명		: gvnoLoanNo</p>
	 * <p>설명			: 미확인 대출번호 채번(입금인불명일때)
	 * 						U0601000001, 11자리, [U] + [YYMM] + [00000X]</p>
	 * <p>메소드인수1	: String acctDt</p>
	 * <p>메소드리턴값	: String</p>
	 * <p>예외처리		: N/A</p>
	 */
	@Override
	public String gvnoLoanNo(String acctDt){
		if ("".equals(acctDt) || (acctDt.length() < 8)) {
			throw new BizException("미확인 대출번호 채번중 에러발생 : 회계일자가 입력되지 않았습니다.");
		}

		String sRtn = "";
		try {

			sRtn = "U" + StringUtil.getFormatDt(acctDt,"").substring(2,6) + rcptService.getNextNum();
		} catch ( Exception e ) {
			return "";
		}
		return sRtn;
	}

	/**
	 * <p>메소드명	: addWkdt</p>
	 * <p>설　　명	: 날짜계산 (영업일, input이 휴일일경우 당일포함)</p>
	 * <p>메소드인수	: String baseDt, int addDayCnt</p>
	 * <p>리　턴　값	: String date</p>
	 */
	@Override
	public String addWkdt(String baseDt, int addDayCnt) throws Exception {
		String wkDt = "";

		try {
			CommBizINDTO inDto = new CommBizINDTO();
			inDto.setBaseDt(baseDt);
			inDto.setAddDayCnt(addDayCnt);

			wkDt = commBizMapper.selectAddWkdt(inDto);
		} catch ( Exception e ) {
			return "";
		}

		return wkDt;
	}

	/**
	 * <p>메소드명	: isChk</p>
	 * <p>설　　명	: 체크값 조회</p>
	 * <p>메소드인수	: Connection, 업무코드코드, 내역번호</p>
	 * <p>리　턴　값	: boolean</p>
	 */
	@Override
	public boolean isChk(String kindNo, String descNo) throws Exception {
		CommCdVO inVO = new CommCdVO(kindNo, descNo);
		String yn = Constants.YN_N;

		try {

			List<CommCdVO> outVO = searchCommCdList(inVO);

			if (outVO.size() > 0 ) {
				yn = outVO.get(0).getClas1();
			}

		} catch (Exception e) {
			throw new BizException("체크값 조회 오류");
		}

		boolean b = Constants.YN_Y.equals(yn);

		return b;
	}

	/**
	 * <p>메소드명	: searchCommCdList</p>
	 * <p>설　　명	: 공통코드 조회</p>
	 * <p>메소드인수	: CommCdVO</p>
	 * <p>리　턴　값	: List</p>
	 */
	@Override
	public List<CommCdVO> searchCommCdList(CommCdVO inVO) throws Exception {

		List<CommCdVO> outVO = commBizMapper.searchCommCdList(inVO);

		return outVO;
	}

	 /**
     * <p>분류종류번호와 분류번호 1~6을 넣고 채번된 값을 반환한다.
     * @param clasKindNo 채번코드번호
     * @param clasNo1 분류번호1
     * @param clasNo2 분류번호2
     * @param clasNo3 분류번호3
     * @param clasNo4 분류번호4
     * @param clasNo5 분류번호5
     * @param clasNo6 분류번호6
     * @param empNo 채번을 요청한 담당자번호
     * @param tx
     * @return
     * @throws DAOException
     */
	@Override
    public String getNextNumber(String clasKindNo,String clasNo1,String clasNo2,String clasNo3
        ,String clasNo4,String clasNo5,String clasNo6,String empNo) throws Exception {

        String sData = "";

        ProcGetNextNumberDTO inDTO = new ProcGetNextNumberDTO();
        inDTO.setClasKindNo(clasKindNo);
        inDTO.setClasNo1(clasNo1);
        inDTO.setClasNo2(clasNo2);
        inDTO.setClasNo3(clasNo3);
        inDTO.setClasNo4(clasNo4);
        inDTO.setClasNo5(clasNo5);
        inDTO.setClasNo6(clasNo6);
        inDTO.setEmpNo(empNo);

        ProcGetNextNumberDTO outDTO = commBizMapper.procGetNextNumber(inDTO);

		if(outDTO != null) {
			if( StringUtils.isNotEmpty(outDTO.getErrMsg())){
				throw new Exception(outDTO.getErrMsg());
			}
			else {
				sData = outDTO.getLastNo();
			}
		}

        LOGGER.debug("채번 결과====>"+sData);

        return sData;
    }

    /**
     * 설정항목 여부 조회
     * @param cdKindNo
     * @param cdDescNo
     * @return boolean bRtn
     */
    @Override
    public boolean isOk(String cdKindNo, String cdDescNo){
    	boolean bRtn = false;
        try {
            /** 공통코드 조회 입력값 전달 객체 선언 및 입력값 대입 */
        	CtCommCdDescDTO inVo = new CtCommCdDescDTO();
            inVo.setCdKindNo(cdKindNo); /* 코드종류번호 */
            inVo.setCdDescNo(cdDescNo); /* 코드상세번호 */

            /** 공통코드 조회 서비스 호출 수행 후 결과값 전달 */
            CtCommCdDescDTO outDTO = ctCommCdDescMapper.select(inVo);

            if(outDTO != null) {
            	if("1".equals(outDTO.getCdDescKorNm())) {
            		bRtn = true;
            	}
            }
        } catch (Exception e) {
            return bRtn;
        }

        return bRtn;
    }

    /**
     * 청구입금배치부서코드 검색(처리사원/부서, 처리일자/시각을 조회)
     * @param cdKindNo
     * @param cdDescNo
     * @return boolean bRtn
     */
    @Override
    public ProcObj getBatchProcInfo() {

        ProcObj procObj = new ProcObj();

        try {
            SearchBatchProcInfoOutDTO outDTO = procSysMapper.searchBatchProcInfo();


            procObj.setProcDt(outDTO.getProcDt()); //시스템반영일자
            procObj.setProcTm(outDTO.getProcTm()); //시스템반영시간
            procObj.setJobDt(outDTO.getProcDt()); //작업_일자
            procObj.setJobTm(outDTO.getJobTm()); //작업_시각
            procObj.setIsrtDeptCd(outDTO.getIsrtDeptCd());
            procObj.setIsrtEmpNo(outDTO.getIsrtEmpNo());
            procObj.setFetchCnt(outDTO.getFetchCnt());
        } catch (Exception e) {
            throw new BizException("청구입금 배치담당 사원,부서정보를 찾을수 없습니다. 공통코드종류번호(R00038) 확인", e);
        }

        return procObj;
    }

    /**
     * 운영시간 조회
     * @param cdKindNo
     * @param cdDescNo
     * @return Array [from, to]
     */
    @Override
    public String[] getOprTm(String cdDescNo) throws Exception {

        CommCdVO param = new CommCdVO("RTM001", "");
        if (StringUtil.isNum(cdDescNo)) {
            param.setCdDescNo(cdDescNo);
        } else {
            param.setEngNm(cdDescNo);
        }

        List<CommCdVO> outVO = searchCommCdList(param);
        if (outVO==null) {
            throw new Exception("운영시간 등록을 확인하세요. (공통코드:RTM001 - "+cdDescNo+")");
        }
        return new String[]{outVO.get(0).getClas1(), outVO.get(0).getClas2()};
    }

    /**
     * 고객 핸드폰번호
     * @param loanNo - 대출번호
     * @param loanSeq - 대출순번
     * @param custGb - 구분(1:계약자, 2:실납입자)
     * @return String []
     */
    @Override
    public String[] getHpNo(String loanNo, String loanSeq, String custGb) throws Exception {

        GetHpNoByLoanNoDTO InVO = new GetHpNoByLoanNoDTO();
        InVO.setLoanNo(loanNo);
        InVO.setLoanSeq(loanSeq);
        InVO.setCustGb(custGb);

        GetHpNoByLoanNoDTO OutVO = commBizMapper.getHpNo(InVO);

        return new String[]{OutVO.getCntcPlcTel1(), OutVO.getCntcPlcTel2(), OutVO.getCntcPlcTel3()};
    }
}
